#
# spec file for package nst
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define version 1.1

Name:           nst
Version:        %{version}
Release:        1.1
Summary:        C++ port of suckless.org st (simple-terminal) emulator
License:        MIT
Group:          System/X11/Terminals
URL:            https://github.com/gerstner-hub/nst
Source0:        nst-v1.1.tar.xz
Source1:        nst_config.cxx
Source2:        nst_config.hxx
Patch0:         usr_etc_lookup.patch

BuildRequires:  asciidoc
BuildRequires:  gcc-c++
BuildRequires:  libXft-devel
BuildRequires:  libcosmos-devel
BuildRequires:  libxpp-devel
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig
BuildRequires:  scons
BuildRequires:  tclap

%description
The not (so) simple terminal emulator. It is a C++ port of st, the simple
terminal emulator for X that sucks less. Apart from a modernized code base
nst offers builtin scrollback buffer support, enhanced smart selection
features and the possibility to process the terminal buffer history in
external tools for searching.

%prep
%setup -q -n %{name}-v%{version}
%autopatch -p1
# copy compile time configuration from package sources into source tree
cp %{SOURCE1} src
cp %{SOURCE2} src

%build
scons libtype=shared use-system-pkgs=1

%install
scons install instroot=%{buildroot}/usr use-system-pkgs=1

%files
%license LICENSE
%doc README.md
%{_bindir}/nst*
%{_distconfdir}/nst.conf
%{_datadir}/applications/%{name}.desktop
%{_datadir}/terminfo/n/nst*
%{_mandir}/man1/nst*
%{_mandir}/man5/nst*

%changelog
* Wed Aug 14 2024 Matthias Gerstner <matthias.gerstner@suse.com>
- switch to using the now available upstream source tarball instead of a Git
  tarball created via the OSC service.
- Update to upstream version 1.1:
  - when using a blinking cursor style, then the blinking was always turned off
    once X11 input occurs. This was confusing when continously inputting
    characters. In this release this no longer happens.
  - performance improvement in the URL snap selection algorithm, which wrongly
    copied the entire screen content in its algorithm.
  - when doing a snap selection that spans multiple lines (e.g. extending a
    long http:// URL), then excess newlines occured, when pasting the selection.
    This no longer happens.
* Tue Jul  2 2024 matthias.gerstner@suse.com
- some stability and other bugfixes
- change of selection handling: addition full line selection mode and changed
  modifier keys.
- Update to version 1.0+git56dd2cb:
  * Selection: only extend to end position for range modes
  * Selection: properly render selection upon initial update()
  * README.md: fix punctuation, grammar, clarity and update to current state
  * TermWindow: reset only non-window-system related state
  * XEventHandler: address FIXME by clarifying the situation
  * interactive.py: support enabling mouse-report
  * TTY: drop FIXME that cannot be fixed (at least not here)
  * README: document new selection features and project situation
  * Selection: harmonize and simplify interface and logic
  * Selection: use Mode enum instead of Snap plus Flags
  * Selection: further renaming of constants; use accessors more consistently
  * Selection: rename context to flags and Context to Flags
  * Selection: cleanup, improve and fix logic for all selection modes
  * types: returns absolute Height(), not negative values
  * README.md: document fuzzing efforts
  * WindowSystem: also reset TermWindow WinMode state
  * Term: deleteColsAfterCursor(): fix wide character deletion
  * Term: improve reset() completeness
  * Term::reset(): properly reset terminal mode
  * CSIEscape: fix some typos
  * .gitignore: ignore all kinds of install trees
  * CSIEscape: implement clear screen + scrollback buffer sequence
  * Term::repeatChar: cap maximum number of character repeats
  * StringEscape: fix possible assertion trying to access null-byte in string_view
  * global: remove unnecessary nst:: namespace qualifications
  * libcosmos: update to version with better compiler support (for AFL)
  * TTY: further fix bad SIGCHILD handling logic
  * Term: remove not applicable TODO about autowrap mode disabling
  * interactive: better command mode on/off parsing; support autowrap setting
  * Term: better compatibility to Xterm regarding alt screen escape codes
  * interactive: support more altscreen operations
  * bugfix: correctly clear window borders when required
  * Line: clarify TODO, this logic has proven robust so far
  * codecs: fix some typos and clarify TODO
  * ColorManager: address TODO by moving code into a separate member function
  * font: evaluate FcFontSort result
  * interactive.py: usability improvements
  * Term: fix insert mode when entering a wide character at the end of a row
  * interactive.py: support setting insert mode
  * interactive.py: support three separate VIM like modes
  * Selection: don't scroll selection from the other screen
* Thu Mar 14 2024 matthias.gerstner@suse.com
- Update to version 1.0+git3df8353:
  * README.md: document configuration file support
  * nst: make external command to receive terminal buffer configurable
  * doc: update and complement man pages
  * nst: support extra configuration file specified in environment variable
  * Cmdline: support additional config file specification
  * SConstruct files: fix flake8 findings
  * XEventHandler: support ConfigFile override of KbdShortcuts
  * themes: gruvbox: fix invalid reverse cursor color index
  * nst: support color configuration via ConfigFile
  * Screen: asText(): don't add newlines for wrapped lines
  * themes: make theme configurable via ConfigFile
  * global: use runtime defined Theme structure
  * Theme: use std::vector for extended colors
  * Selection: make SEL_URI_SCHEMES configurable via ConfigFile
  * Term: make HISTORY_LEN configurable via ConfigFile
  * WindowSystem: make HIDE_MOUSE_CURSOR configurable via ConfigFile
  * Term: make KEEP_SCROLL_POSITION configurable via ConfigFile
  * WindowSystem: support configuration of COLS and ROWS via ConfigFile
  * WindowSystem: support configuration of CURSORSHAPE via ConfigFile
  * WindowSystem: make CURSOR_THICKNESS configurable via ConfigFile
  * nst: make BLINK_TIMEOUT configurable via ConfigFile
  * Selection: make SEL_LINE_SNAP_KEEP_NEWLINE configurable via ConfigFile
  * XEventHandler: support configuring SEL_CLEAR via ConfigFile
  * ConfigFile: support obtaining boolean config values
  * WindowSystem: support configuration of BORDER_PX via ConfigFile
  * TTY: bad SIGCHILD handling logic
  * Selection: support configuring WORD_DELIMITERS via configuration file
  * ConfigFile: support getting wstring config values
  * ConfigFile: support unicode strings and proper string quoting style
  * feature: add support for a simple configuration file
  * README.md: reflect latest development efforts
  * README.md: fix some typos
  * CSIEscape: fix error message in parseColor()
  * nst-msg: support operating on specific instance by passing PID
- add usr_etc_lookup.patch: lookup config in /usr/etc as well.
* Tue Feb 20 2024 Matthias Gerstner <matthias.gerstner@suse.com>
- initial version of the package
